package Role::HasPayload::Meta::Attribute::Payload;
{
  $Role::HasPayload::Meta::Attribute::Payload::VERSION = '0.006';
}
use Moose::Role;
# ABSTRACT: a meta-trait for attributes forming the autopayload


1;

__END__

=pod

=head1 NAME

Role::HasPayload::Meta::Attribute::Payload - a meta-trait for attributes forming the autopayload

=head1 VERSION

version 0.006

=head1 DESCRIPTION

This package basically does nothing but serve as a marker.  You want to look at
the docs for L<Role::HasPayload::Auto> instead.

=head1 AUTHOR

Ricardo Signes <rjbs@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Ricardo Signes.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
